<?php

namespace Teknisa\CADSUP\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class Sup02400CalendarioDeDiasNaoUteisService {
    protected $connection;
    
    public function __construct($entityManager, $environment){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    public function getErrosRequisicao($row){

		$param = array(
		    'P_CDFILIAL' => $row['CDFILIAL'],
		    'P_DTLANCTO' => $row['DTDIA']
		);
		
        $query = "SELECT 'E' AS IDTIPO, NRREQUESTO AS NRO
                    FROM REQUESTO R
                    WHERE
                      (R.CDFILIAL    = :P_CDFILIAL ) AND
                      (R.DTREQUESTO  = :P_DTLANCTO )
                    
                    UNION ALL
                    
                    SELECT 'R' AS IDTIPO, NRREQUEXTR AS NRO
                    FROM PREVRETI PR
                    WHERE
                     (PR.CDFILIAL   = :P_CDFILIAL)   AND
                     (PR.DTPREVRETI = :P_DTLANCTO)
                    ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function getErrosEfetivos($row){

		$param = array(
		    'P_CDFILIAL' => $row['CDFILIAL'],
		    'P_DTLANCTO' => $row['DTDIA']
		);
		
        $query = "SELECT CDFILIAL
                    FROM EFETCLIE
                    WHERE
                       CDFILIAL     = :P_CDFILIAL     AND
                       DTEFETCLIE   = :P_DTLANCTO
                    
                    UNION ALL
                    
                    SELECT CDFILIAL
                    FROM EFECLIFAT
                    WHERE
                       CDFILIAL     = :P_CDFILIAL     AND
                       DTFATURAM    = :P_DTLANCTO
                    
                    UNION ALL
                    
                    SELECT CDFILIAL
                    FROM EFECLIFATTUR
                    WHERE
                       CDFILIAL     = :P_CDFILIAL     AND
                       DTFATURAMTUR = :P_DTLANCTO

                    ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    
    
    public function selectCardUnidadeCentralMerenda($row){
		$param = array(
		    'CDFILIAL' => $row['CDFILIAL'],
		    'DTCARDIAPME' => $row['DTCARDIAPME'],
		    'DTPROCESSA' => $row['DTPROCE']
		);
		
        $query = "
                SELECT CARDIAPME.NRCARDPME, CARDIAPME.NRCARDIAPME, CARDIAPME.CDFILCENTPME, CARDIAPME.CDFILIAL,
                    CARDIAPME.DTCARDIAPME
                    FROM CARDIAPME
                    WHERE (CARDIAPME.CDFILIAL = :CDFILIAL)
                    AND (CARDIAPME.DTCARDIAPME = :DTCARDIAPME)
                    AND (CARDIAPME.DTCARDIAPME >= :DTPROCESSA)
                    ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }        
    }
    
    public function deleteCardUnidadeCentralMerenda($row){
        $param = array(
		    'CDFILCENTPME' => $row['CDFILCENTPME'],
		    'NRCARDPME' => $row['NRCARDPME'],
		    'NRCARDIAPME' => $row['NRCARDIAPME']
		);
		
        $query = "
                DELETE
                FROM COMPCARDPME
                WHERE CDFILCENTPME = :CDFILCENTPME
                AND NRCARDPME = :NRCARDPME
                AND NRCARDIAPME = :NRCARDIAPME
            ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    

    
    public function deleteCardUnidadeCentralAposLacoMerenda($row){
        $param = array(
		    'CDFILCENTPME' => $row['CDFILCENTPME'],
		    'DTCARDIAPME' => $row['DTCARDIAPME'],
		    'DATAPROC' => $row['DTPROCE']
		);
		
        $query = "
                DELETE
                FROM CARDIAPME
                WHERE
               (CARDIAPME.CDFILCENTPME = :CDFILCENTPME) AND
               (CARDIAPME.DTCARDIAPME  = :DTCARDIAPME)  AND
               (CARDIAPME.DTCARDIAPME >= :DATAPROC)
            ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    public function deleteCardUnidadeMerenda($row){
        $param = array(
		    'CDFILCENTPME' => $row['CDFILCENTPME'],
		    'NRCARDPME' => $row['NRCARDPME'],
		    'NRCARDIAPME' => $row['NRCARDIAPME']
		);
		
        $query = "
                DELETE
                FROM COMPCARDPME
                WHERE NRCARDPME = :NRCARDPME
                AND NRCARDIAPME = :NRCARDIAPME
                AND CDFILCENTPME = :CDFILCENTPME
            ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    public function deleteCardUnidadeAposLacoMerenda($row){
        $param = array(
		    'CDFILIAL' => $row['CDFILIAL'],
		    'DTCARDIAPME' => $row['DTCARDIAPME'],
		    'DATAPROC' => $row['DTPROCE']
		);
		
        $query = "
                DELETE
                FROM CARDIAPME
                WHERE
                   (CARDIAPME.CDFILIAL  = :CDFILIAL) AND
                   (CARDIAPME.DTCARDIAPME  = :DTCARDIAPME)  AND
                   (CARDIAPME.DTCARDIAPME >= :DATAPROC)
            ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }        
    }
    
    public function deleteCardIndustrial($row){
        $param = array(
		    'CDFILIAL' => $row['CDFILIAL'],
		    'DTCARDAPIO' => $row['DTCARDAPIO'],
		    'DATAPROC' => $row['DTPROCE']
		);
		
        $query = "

                DELETE
                FROM CARDADIA
                WHERE
                   (CARDADIA.CDFILIAL   =  :CDFILIAL)   AND
                   (CARDADIA.DTCARDAPIO =  :DTCARDAPIO) AND
                   (CARDADIA.DTCARDAPIO >= :DATAPROC)   AND
                   NOT EXISTS (SELECT RETIRADA.NRRETIRADA
               FROM
                  RETIRADA
               WHERE
                  (RETIRADA.CDFILIAL   = CARDADIA.CDFILIAL)   AND
                  (RETIRADA.NRCARDAPIO = CARDADIA.NRCARDAPIO))
            ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }        
    }
    
    public function possuiNFE($row){

		$param = array(
		    'CDFILIRECE' => $row['CDFILIAL'],
		    'DTENTRSAID' => $row['DTDIA'],
		    'NRORG' => $row['NRORG']
		    
		);
		
        $query = "SELECT *
                    FROM NOTAFISCAL
                    WHERE
                      (CDFILIRECE    = :CDFILIRECE ) AND
                      (DTENTRSAID  = :DTENTRSAID ) AND
                        (NRORG  = :NRORG )
                    ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function possuiNFS($row){
    $param = array(
		    'CDFILIEMIT' => $row['CDFILIAL'],
		    'DTENTRSAID' => $row['DTDIA'],
		    'NRORG' => $row['NRORG']
		    
		);
		
        $query = "SELECT *
                    FROM NOTAFISCAL
                    WHERE
                      (CDFILIEMIT    = :CDFILIEMIT ) AND
                      (DTENTRSAID  = :DTENTRSAID ) AND
                        (NRORG  = :NRORG )
                    ";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
}